@@ -33,6 +33,7 @@
 #include <goffice/goffice-config.h>
 #include <goffice/math/go-math.h>
 #include "go-dtoa.h"
+#include "go-ryu.h"
 #include <string.h>
 #include <inttypes.h>
 #include <stdarg.h>
@@ -156,10 +157,6 @@ static int fmt_fp(FAKE_FILE *f, long double y, int w, int p, int fl, int t)
 	int pl;
 	char ebuf0[3*sizeof(int)], *ebuf=&ebuf0[3*sizeof(int)], *estr;
 
-#ifndef MUSL_ORIGINAL
-	if (fl & FLAG_TRUNCATE) g_string_truncate (f, 0);
-#endif
-
 	pl=1;
 	if (signbit(y)) {
 		y=-y;
@@ -457,28 +454,67 @@ parse_fmt (const char *fmt, va_list args, gboolean *is_long,
 		*d = va_arg (args, double);
 }
 
-static long double
-strto (const char *str, gboolean is_long, gboolean is_ascii)
+static void
+fmt_shortest (GString *dst, long double d, int fl, int t, gboolean is_long)
 {
-	if (is_long) {
-#ifdef GOFFICE_WITH_LONG_DOUBLE
-		/*
-		 * FIXME: ignore ascii flag for now.  Given the limited
-		 * and checked usage of this function this should still
-		 * be safe, if suboptimal.
-		 */
-		return go_strtold (str, NULL);
-#else
-		return go_nan;
-#endif
+	size_t oldlen = dst->len;
+	int n, e, ndec;
+	char *epos, *dpos;
+	gboolean use_e_notation;
+	GString const *dec = go_locale_get_decimal();
+
+	g_string_set_size (dst, 53 + oldlen + dec->len);
+	if (is_long)
+		n = go_ryu_ld2s_buffered_n (d, dst->str + oldlen);
+	else
+		n = go_ryu_d2s_buffered_n ((double)d, dst->str + oldlen);
+	g_string_set_size (dst, oldlen + n);
+	dpos = strchr (dst->str + oldlen, '.');
+	epos = strchr (dst->str + oldlen, 'E');
+	ndec = dpos
+		? (epos
+		   ? epos - (dpos + 1)
+		   : (int)(dst->len - (dpos + 1 - dst->str)))
+		: 0;
+	if (!epos)
+		return; // NaN etc.
+
+	if (dpos && !(fl & FLAG_ASCII)) {
+		int dlen = dec->len;
+		const char *dstr = dec->str;
+		*dpos = dstr[0];
+		if (dlen > 1) {
+			g_string_insert_len (dst, dpos - dst->str + 1,
+					     dstr + 1, dlen - 1);
+			epos += dlen - 1;
+			// We allocated enough that dpos/epos are still good
+		}
+	}
+
+	e = atoi (epos + 1);
+	use_e_notation =
+		(t | 32) == 'e' ||
+		((t | 32) == 'g' && (e < -4 || e >= (is_long ? 21 : 17)));
+	if (use_e_notation) {
+		// Downcase 'E', if needed
+		if (t & 32) *epos = 'e';
+		// Use printf rules for exponents
+		if (e >= 0 && e <= 9)
+			g_string_insert (dst, epos - dst->str + 1, "+0");
+		else if (e >= 10)
+			g_string_insert_c (dst, epos - dst->str + 1, '+');
+		else if (e >= -9 && e < 0)
+			g_string_insert_c (dst, epos - dst->str + 2, '0');
+		return;
 	} else {
-		return is_ascii
-			? g_ascii_strtod (str, NULL)
-			: go_strtod (str, NULL);
+		// Else f-notation.  Redo.
+		int precision = MAX (0, ndec - e);
+		t = (t & 32) | 'F';
+		g_string_set_size (dst, oldlen);
+		fmt_fp (dst, d, 1, precision, fl, t);
 	}
 }
 
-
 void
 go_dtoa (GString *dst, const char *fmt, ...)
 {
@@ -487,7 +523,6 @@ go_dtoa (GString *dst, const char *fmt, ...)
 	long double d;
 	gboolean is_long;
 	gboolean debug = FALSE;
-	size_t oldlen;
 #ifdef ENSURE_FPU_STATE
 	fpu_control_t oldstate;
 	const fpu_control_t mask = _FPU_EXTENDED | _FPU_DOUBLE | _FPU_SINGLE;
@@ -497,8 +532,9 @@ go_dtoa (GString *dst, const char *fmt, ...)
 	parse_fmt (fmt, args, &is_long, &w, &p, &fl, &t, &d);
 	va_end (args);
 
-	if (fl & FLAG_SHORTEST) p = is_long ? 21 : 17;
-	oldlen = (fl & FLAG_TRUNCATE) ? 0 : dst->len;
+	if (fl & FLAG_TRUNCATE) g_string_truncate (dst, 0);
+
+	if (debug) g_printerr ("%Lg [%s] t=%c  p=%d\n", d, fmt, t, p);
 
 #ifdef ENSURE_FPU_STATE
 	// fmt_fp depends on "long double" behaving right.  That means that the
@@ -512,55 +548,16 @@ go_dtoa (GString *dst, const char *fmt, ...)
 	}
 #endif
 
-	if (debug) g_printerr ("%Lg [%s] t=%c  p=%d\n", d, fmt, t, p);
-	fmt_fp (dst, d, w, p, fl, t);
-	if (debug) g_printerr ("  --> %s\n", dst->str);
-
-	if (fl & FLAG_SHORTEST) {
-		GString *alt = g_string_new (NULL);
-		const char *dec = (fl & FLAG_ASCII)
-			? "."
-			: go_locale_get_decimal()->str;
-		while (p > 0) {
-			ssize_t len_dif;
-			const char *dot = strstr (dst->str + oldlen, dec);
-			long double dalt;
-			if (!dot)
-				break;
-
-			/*
-			 * This is crude.  We have a dot, so try to render
-			 * the same number with less precision and check
-			 * that the result round-trips.
-			 */
-
-			fmt_fp (alt, d, w, p - 1, fl | FLAG_TRUNCATE, t);
-			len_dif = dst->len - oldlen - alt->len;
-
-			if (len_dif == 0) {
-				/* Same string so we've already removed 0s. */
-				break;
-			}
-
-			dalt = strto (alt->str, is_long, (fl & FLAG_ASCII));
-			if (dalt != d)
-				break;
-
-			g_string_truncate (dst, oldlen);
-			go_string_append_gstring (dst, alt);
-			if (debug) g_printerr ("  --> %s\n", dst->str);
-
-			p--;
-
-			if (len_dif > 1)
-				break;
-		}
-		g_string_free (alt, TRUE);
-	}
+	if (fl & FLAG_SHORTEST)
+		fmt_shortest (dst, d, fl, t, is_long);
+	else
+		fmt_fp (dst, d, w, p, fl, t);
 
 #ifdef ENSURE_FPU_STATE
 	if ((oldstate & mask) != _FPU_EXTENDED) {
 		_FPU_SETCW (oldstate);
 	}
 #endif
+
+	if (debug) g_printerr ("  --> %s\n", dst->str);
 }
