@@ -823,9 +823,7 @@ go_fake_floorl (long double x)
 	if (x == floorl (x))
 		return x;
 
-	return (x >= 0)
-		? floorl (go_add_epsilonl (x))
-		: floorl (go_sub_epsilonl (x));
+	return floorl (go_add_epsilonl (x));
 }
 
 long double
@@ -834,9 +832,7 @@ go_fake_ceill (long double x)
 	if (x == floorl (x))
 		return x;
 
-	return (x >= 0)
-		? ceill (go_sub_epsilonl (x))
-		: ceill (go_add_epsilonl (x));
+	return ceill (go_sub_epsilonl (x));
 }
 
 long double
@@ -1183,7 +1179,7 @@ double
 go_cotpi (double x)
 {
 	/*
-	 * IEEE 754 2008 doesn't have tanpi.  Neither does crlibm.  Mirror
+	 * IEEE 754 2008 doesn't have cotpi.  Neither does crlibm.  Mirror
 	 * tanpi here.
 	 */
 
@@ -1336,7 +1332,7 @@ long double
 go_cotpil (long double x)
 {
 	/*
-	 * IEEE 754 2008 doesn't have tanpi.  Neither does crlibm.  Mirror
+	 * IEEE 754 2008 doesn't have cotpi.  Neither does crlibm.  Mirror
 	 * tanpi here.
 	 */
 
