@@ -443,7 +443,7 @@ struct _GOMemChunk {
 
 
 GOMemChunk *
-go_mem_chunk_new (char const *name, size_t user_atom_size, size_t chunk_size)
+go_mem_chunk_new (char const *name, gsize user_atom_size, gsize chunk_size)
 {
 	int atoms_per_block;
 	GOMemChunk *res;
@@ -732,7 +732,7 @@ go_str_compare (void const *x, void const *y)
 
 
 const char *
-go_guess_encoding (const char *raw, size_t len, const char *user_guess,
+go_guess_encoding (const char *raw, gsize len, const char *user_guess,
 		   GString **utf8_str, guint *truncated)
 {
 	int try;
@@ -854,6 +854,47 @@ go_destroy_password (char *passwd)
 }
 
 
+/**
+ * go_memdup:
+ * @mem: (nullable): Memory to copy
+ * @byte_size: size of memory block to copy
+ *
+ * Like g_memdup or g_memdup2.  This function is meant to ease transition
+ * to g_memdup2 without having to require very new glib.
+ **/
+gpointer
+go_memdup (gconstpointer mem, gsize byte_size)
+{
+	if (mem && byte_size != 0) {
+		gpointer new_mem = g_malloc (byte_size);
+		memcpy (new_mem, mem, byte_size);
+		return new_mem;
+	} else
+		return NULL;
+}
+
+/**
+ * go_memdup_n:
+ * @mem: (nullable): Memory to copy
+ * @n_blocks: Number of blocks to copy.
+ * @block_size: Number of bytes per blocks.
+ *
+ * Like go_memdup (@mem, @n_blocks * @block_size), but with overflow check.
+ * Like a potential future g_memdup_n.
+ **/
+gpointer
+go_memdup_n (gconstpointer mem, gsize n_blocks, gsize block_size)
+{
+	if (mem && n_blocks > 0 && block_size > 0) {
+		gpointer new_mem = g_malloc_n (n_blocks, block_size);
+		memcpy (new_mem, mem, n_blocks * block_size);
+		return new_mem;
+	} else
+		return NULL;
+}       
+
+
+
 /**
  * go_object_toggle:
  * @object: #GObject
