@@ -79,9 +79,14 @@ xl_xyz_series_class_init (GogStyledObjectClass *gso_klass)
 	obj_klass->update = xl_xyz_series_update;
 }
 
+static void
+xl_xyz_series_init (GogSeries *series)
+{
+	series->has_legend = FALSE;
+}
 
 GSF_DYNAMIC_CLASS (XLXYZSeries, xl_xyz_series,
-	xl_xyz_series_class_init, NULL,
+	xl_xyz_series_class_init, xl_xyz_series_init,
 	GOG_TYPE_SERIES)
 
 /*****************************************************************************/
@@ -153,7 +158,7 @@ get_y_vector (GogPlot *plot)
 	g_free (*y_labels);
 	*y_labels = g_new0 (char const *, GOG_XYZ_PLOT (plot)->rows);
 
-	for (ptr = plot->series, i = 0 ; ptr != NULL ; ptr = ptr->next, i++) {
+	for (ptr = plot->series, i = 0 ; ptr != NULL ; ptr = ptr->next) {
 		XLXYZSeries *series = ptr->data;
 
 		if (!gog_series_is_valid (GOG_SERIES (series)))
@@ -161,6 +166,7 @@ get_y_vector (GogPlot *plot)
 		(*y_labels) [i] = (series->values[-1].data)?
 				go_data_get_scalar_string (series->values[-1].data):
 				g_strdup_printf("S%d", i + 1); /* excel like labels */
+		i++;
 	}
 
 	return GO_DATA (go_data_vector_str_new (*y_labels, i, g_free));
@@ -270,6 +276,7 @@ xl_contour_plot_build_matrix (GogXYZPlot *plot, gboolean *cardinality_changed)
 		series->num_elements = has_scale? 1: max;
 		*cardinality_changed = TRUE;
 	}
+	GOG_CONTOUR_PLOT (plot)->max_colors = max;
 	gog_axis_map_free (map);
 	return data;
 }
